# UiPathApi

[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)

[Tutorial: Packaging Guide](https://packaging.python.org/en/latest/tutorials/packaging-projects/)

[Using OAuth for External Apps](https://docs.uipath.com/orchestrator/reference/using-oauth-for-external-apps)

[Swagger](https://sb.akoa.com/swagger/index.html)

[Test PyPi - uipath-api-tools](https://test.pypi.org/project/uipath-api-tools/)

[Example Project](https://github.com/tagmeh/uipath-api)